@@ -1,4 +1,4 @@
-from .loading_bar import spinner, loading_bar
+from .loading import spinner, bar as loading_bar
 
 __all__ = [
     'spinner',
